#!/bin/bash
#############################################################################
# PROGRAM
#     cp2srv.sh
#
# SYNOPSIS
#     Used to copy a file to several ftp/ssh servers at once.
#
# USAGE
#     cp2srv.sh [localfile] [remotefile]
#
# OPTIONS
#     localfile		file path on local machine
#     remotefile	name to give file on remote machine
#
# REQUIRED
#     None
#
# AUTHOR
#     Steve Dickinson
#
# COMMENTS
#
# Development     : 02.14.07
# Initial Release : 02.15.07
#
# REVISIONS
#############################################################################
# VARIABLES
#############################################################################
PROGRAM=`basename $0`

#----------------------------------------------------------------------------
# DEFINE FTP SERVERS
# FTP_SERVERS = ftp server ips to connect to (they must all have the
#               same login/password)
#   FTP_LOGIN = server login
# FTP_PASWORD = server password
#    FTP_PATH = absolute path to put file in
#----------------------------------------------------------------------------
FTP_SERVERS=('ip1' 'ip2' 'ip3')
FTP_LOGIN="login"
FTP_PASSWORD="password"
FTP_PATH="/put/file/here"

#----------------------------------------------------------------------------
# DEFINE SSH SERVERS
# SSH_SERVERS = ssh server ips to connect to (they must all have the
#               same login/password)
#   SSH_LOGIN = server login
# SSH_PASWORD = server password
#    SSH_PATH = absolute path to put file in
#----------------------------------------------------------------------------
SSH_SERVERS=('ip1' 'ip2' 'ip3')
SSH_LOGIN="login"
SSH_PASSWORD="password"
SSH_PATH="/put/file/here"

#----------------------------------------------------------------------------
# GET PASSED IN PARAMETERS
#----------------------------------------------------------------------------
LOCALFILE=$1
REMOTEFILE=$2

#############################################################################
# USAGE
#############################################################################
function usage {
	printf "\nusage: $PROGRAM [localfile] [remotefile]\n\n"
    printf "Parameters:\n"
    printf "  localfile		file path on local machine\n"
	printf "  remotefile	name to give file on remote machine\n"
    printf "\n"
	exit
}

#############################################################################
# ERROR
#############################################################################
function error {
	printf "\n\n$1\n"
	exit
}
	
#############################################################################
# MAIN
#############################################################################
#----------------------------------------------------------------------------
# DO SOME CHECKS
#----------------------------------------------------------------------------
if [ ! $# == 2 ]; then
	usage
fi

if [ ! -f $LOCALFILE ]; then
	error "$PROGRAM: File $LOCALFILE not found!"
fi

#----------------------------------------------------------------------------
# COPY FILE TO FTP SERVERS
#----------------------------------------------------------------------------
printf "\nTransfering '$LOCALFILE' to specified server locations:\n"
for ip in ${FTP_SERVERS[@]}
do
	echo "$ip updated ..."
ftp -in $ip <<EOF
user $FTP_LOGIN $FTP_PASSWORD
ascii
put $LOCALFILE $FTP_PATH/$REMOTEFILE
quit
EOF

done

#----------------------------------------------------------------------------
# COPY FILE TO SSH SERVERS
#----------------------------------------------------------------------------
for ip in ${SSH_SERVERS[@]}
do
	echo "$ip updated ..."
	scp $LOCALFILE $SSH_LOGIN@$ip:$SSH_PATH/$REMOTEFILE > /dev/null 2>&1
done

exit
